aboutsummaryrefslogtreecommitdiffstats
path: root/mod/dfrn_request.php
diff options
context:
space:
mode:
Diffstat (limited to 'mod/dfrn_request.php')
-rw-r--r--mod/dfrn_request.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/mod/dfrn_request.php b/mod/dfrn_request.php
index dc329aa19..95b2ec3a4 100644
--- a/mod/dfrn_request.php
+++ b/mod/dfrn_request.php
@@ -196,7 +196,7 @@ function dfrn_request_post(&$a) {
// (ignore reply, nothing we can do it failed)
- goaway(zrl($dfrn_url));
+ goaway(zid($dfrn_url));
return; // NOTREACHED
}
@@ -780,7 +780,7 @@ function dfrn_request_content(&$a) {
$myaddr = ((x($_GET,'address')) ? $_GET['address'] : '');
}
// last, try a zrl
if(! strlen($myaddr))
$myaddr = get_my_url();
@@ -780,7 +780,7 @@ function dfrn_request_content(&$a) {
$myaddr = ((x($_GET,'address')) ? $_GET['address'] : '');
}
- // last, try a zrl
+ // last, try a zid
if(! strlen($myaddr))
$myaddr = get_my_url();